==> nui_media-0.0.1.tar.gz: lib/ui/nui_camera_view.dart <==
import 'dart:io';
import 'package:camera/camera.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_animation/nui_animation.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_media/nui_media.dart';

class NUICameraScreenUI extends NUIScreen{
  NUICameraScreenUI(this.cameras, {
    this.resolution: ResolutionPreset.high,
    this.captureButton,
    this.captureButtonMargin,
    this.captureButtonAlignment: Alignment.bottomCenter,
    this.enableVideo: false,
    this.videoMaxDuration,
    this.listener,
    this.preview: true,
    Key key}): super(content : (context) => Scaffold(body: NUICameraUI(cameras: cameras, captureButtonAlignment: captureButtonAlignment, captureButton: captureButton, listener: listener, preview: preview, captureButtonMargin: captureButtonMargin, resolution: resolution, enableVideo: enableVideo, key: key)), screenCode: "NUICameraScreenUI", overlayStyle: NUIOverlayStyle(darkStatusBarIcon: false), key: key);
  final List<CameraDescription> cameras;
  final ResolutionPreset resolution;
  final Widget captureButton;
  final bool enableVideo;
  final Duration videoMaxDuration;
  final Alignment captureButtonAlignment;
  final EdgeInsets captureButtonMargin;
  final MediaSelectionListener listener;
  final bool preview;
}

class NUICameraUI extends StatefulWidget {
  NUICameraUI({
    this.cameras,
    this.resolution: ResolutionPreset.high,
    this.captureButtonMargin,
    this.captureButton,
    this.captureButtonAlignment,
    this.enableVideo: false,
    this.videoMaxDuration,
    this.preview,
    this.listener,
    Key key}): super(key: key);
  final List<CameraDescription> cameras;
  final ResolutionPreset resolution;
  final Widget captureButton;
  final Alignment captureButtonAlignment;
  final bool enableVideo;
  final Duration videoMaxDuration;
  final EdgeInsets captureButtonMargin;
  final MediaSelectionListener listener;
  final bool preview;
  @override
  _NUICameraUIState createState() => _NUICameraUIState();
}

class _NUICameraUIState extends State<NUICameraUI> {
  CameraController _controller;
  int _selectedCameraIndex = 0;
  double scale = 1.0;
  bool isRecording = false;
  bool initiatingRecord = false;
  Future<void> _initializeControllerFuture;
  String recordingVideoPath;


  @override
  void initState(){
    super.initState();
    _initCameraController(widget.cameras[_selectedCameraIndex]);
  }

  void longPress() async{
    print("NUICameraView -> Long pressing");
    if(!widget.enableVideo) return;

    setState(() {
      initiatingRecord = true;
    });
  }

  void capture() async{
    try {
      // Ensure that the camera is initialized.
      await _initializeControllerFuture;

      final file = await NUIMediaUtil.getOutputMediaFile(MediaType.JPG, createFirst: false);
      // Attempt to take a picture and log where it's been saved.
      await _controller.takePicture(file.path);

      if(widget.preview) {
        // If the picture was taken, display it on a new screen.
        NUINavigator.popAndPush(context, NUIImagePreviewUI(imagePath: file.path, enableRecording: widget.enableVideo, listener: widget.listener), transition: PageTransition.RIGHT_LEFT, duration: Duration(milliseconds: 1200));
      }
      else{
        if(widget.listener != null) widget.listener([await NUIMediaUtil.fileToMediaFile(file, type: MediaType.JPG)]);
      }
    } catch (e) {
      // If an error occurs, log the error to the console.
      print(e);
    }
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  Widget _getCaptureRecordButton() {
    final captureButton = Container(
      height: 80,
      width: 80,
      decoration: NUIOutlineDecoration(
          outlineColor: NUIColors.NUIWhite,
          thickness: 3,
          shadowRadius: 10,
          shadowColor: NUIColors.NUIBlack.withOpacity(0.4),
          radius: BorderRadius.circular(40)
      ),
      padding: EdgeInsets.all(4),
      child: NUIBouncingAnimation(
        scaleFactor: 1,
        child: !initiatingRecord && !isRecording ? Container(
          width: 70,
          height: 70,
          decoration: BoxDecoration(
              color: NUIColors.NUIWhite,
              shape: BoxShape.circle
          ),
        ) : Container(
          width: 70,
          height: 70,
          alignment: Alignment.center,
          decoration: BoxDecoration(
            color: NUIColors.NUIWhite,
            shape: BoxShape.circle
          ),
          child: !isRecording ? NUIScaleAnimation(
            duration: Duration(milliseconds: 400),
            child: Container(
              width: 55,
              height: 55,
              decoration: BoxDecoration(
                color: NUIColors.NUIAccent,
                shape: BoxShape.circle
              ),
            ),
            endAnimationListener: () {
              initiatingRecord = false;
              isRecording = true;
            },
          ) : Container(
            width: 55,
            height: 55,
            decoration: BoxDecoration(
                color: NUIColors.NUIAccent,
                shape: BoxShape.circle
            ),
          ),
        ),
        onTap: () {
          capture();
        },
        onLongPress: () {
          longPress();
        },
      ),
    );
    return captureButton;
  }


  Widget _getCaptureButton(){
    Widget captureButton;
    if(widget.captureButton != null){
      captureButton = GestureDetector(
        child: widget.captureButton,
        onTap: (){
          capture();
        },
      );
    }
    else {
      captureButton = _getCaptureRecordButton();
    }

    return Container(
      margin: widget.captureButtonMargin ?? EdgeInsets.all(30),
      child: captureButton,
    );
  }

  Widget _cameraTogglesWidget() {
    if (widget.cameras == null || widget.cameras.isEmpty) {
      return Spacer();
    }

    CameraDescription selectedCamera = widget.cameras[_selectedCameraIndex];
    CameraLensDirection lensDirection = selectedCamera.lensDirection;

    return _NUISmallActionButton(icon: _getCameraLensIcon(lensDirection), onTap: (){
      _switchCamera();
    });
  }

  void _switchCamera() {
    if(widget.cameras.length > 1) {
      _selectedCameraIndex = _selectedCameraIndex == 0 ? 1 : 0;
      CameraDescription selectedCamera = widget.cameras[_selectedCameraIndex];
      _initCameraController(selectedCamera);
    }
  }

  Future _initCameraController(CameraDescription cameraDescription) async {
    if (_controller != null) {
      await _controller.dispose();
    }

    _controller = CameraController(cameraDescription, widget.resolution ?? ResolutionPreset.high);

    _controller.addListener(() {
      if (mounted) {
        setState(() {});
      }

      if (_controller.value.hasError) {
        print('Camera error ${_controller.value.errorDescription}');
      }
    });

    try {
      _initializeControllerFuture = _controller.initialize();
    } on CameraException catch (e) {
//      _showCameraException(e);
    }

    if (mounted) {
      print("NUICameraView -> Camera mounted");
      setState(() {

      });
    }
  }

  IconData _getCameraLensIcon(CameraLensDirection direction) {
    switch (direction) {
      case CameraLensDirection.back:
        return Icons.camera_rear;
      case CameraLensDirection.front:
        return Icons.camera_front;
      case CameraLensDirection.external:
        return Icons.camera;
      default:
        return Icons.device_unknown;
    }
  }

  void _onRecordButtonPressed() {
    _startVideoRecording().then((String filePath) {
      if (filePath != null) {
        toast("Recording video started", context: context);
      }
    });
  }

  void _onStopButtonPressed() {
    _stopVideoRecording().then((_) {
      if (mounted) setState(() {});
      toast("Video recorded to $recordingVideoPath", context: context);
    });
  }

  Future<String> _startVideoRecording() async {
    if (!_controller.value.isInitialized) {
      toast("Please wait", context: context);
      return null;
    }

    // Do nothing if a recording is on progress
    if (_controller.value.isRecordingVideo) {
      return null;
    }

    final File file = await NUIMediaUtil.getOutputMediaFile(MediaType.MP4, createFirst: false);
    final String filePath = file.path;

    try {
      await _controller.startVideoRecording(filePath);
      recordingVideoPath = filePath;
    } on CameraException catch (e) {
      _showCameraException(e);
      return null;
    }
    return filePath;
  }

  Future<void> _stopVideoRecording() async {
    if (!_controller.value.isRecordingVideo) {
      return null;
    }
    try {
      await _controller.stopVideoRecording();
    } on CameraException catch (e) {
      _showCameraException(e);
      return null;
    }
  }

  void _showCameraException(CameraException e) {
    String errorText = 'Error: ${e.code}\nError Message: ${e.description}';
    print(errorText);

    toast("Error: ${e.code}\n${e.description}", context: context);
  }

  @override
  Widget build(BuildContext context) {
    Widget preview;
    if (_controller == null || !_controller.value.isInitialized) {
      preview = Center(child: CircularProgressIndicator());
    }
    else {
      preview = GestureDetector(
          onScaleUpdate: (one) {
//            scale = one.scale;
//            setState(() {
//
//            });
          },
          child: Transform.scale(
              scale: scale,
              child: Center(child: AspectRatio(
                  aspectRatio: _controller.value.aspectRatio,
                  child: CameraPreview(_controller)))
          )
      );
    }

    return Container(
      color: NUIColors.NUIBlack,
      child: Stack(
          children: [
            preview,
            Align(
              alignment: Alignment.topCenter,
              child: Container(
                height: NUIDisplayUtil.statusBarHeight(context) + 20,
                width: screenWidth(context),
                decoration: BoxDecoration(
                    gradient: NUILinearGradient(
                        colors: [
                          NUIColors.NUIShadowBlack.withOpacity(0.4),
                          NUIColors.NUIShadowBlack.withOpacity(0.1),
                          NUIColors.NUITransparent
                        ],
                        orientation: GradientOrientation.T_B
                    )
                ),
              ),
            ),
            Visibility(
                visible: widget.cameras.length > 1,
                child: Align(
                  child: _cameraTogglesWidget(),
                  alignment: Alignment.bottomLeft,
                )
            ),
            Align(
              child: _getCaptureButton(),
              alignment: widget.captureButtonAlignment ??
                  Alignment.bottomCenter,
            )
          ]
      ),
    );
  }
}

class NUIImagePreviewUI extends NUIScreen {
  final String imagePath;
  final MediaSelectionListener listener;
  final bool enableRecording;

  NUIImagePreviewUI({Key key, this.imagePath, this.listener, this.enableRecording}) : super(
      content : (context) => _NUICameraPreviewContentUI(imagePath, listener: listener, enableRecording: enableRecording,), screenCode: "NUIImagePreviewUI", key: key, overlayStyle: NUIOverlayStyle(darkStatusBarIcon: false));
}

class _NUICameraPreviewContentUI extends StatefulWidget {
  _NUICameraPreviewContentUI(this.path, {this.listener, this.enableRecording});
  final String path;
  final MediaSelectionListener listener;
  final bool enableRecording;

  @override
  __NUICameraPreviewContentUIState createState() => __NUICameraPreviewContentUIState();
}

class __NUICameraPreviewContentUIState extends State<_NUICameraPreviewContentUI> {

  @override
  Widget build(BuildContext context) {
    return Container(
      color: NUIColors.NUIBlack,
      child: Stack(
          children: [
            Center(
              child: InteractiveViewer(child: Image.file(File(widget.path)), maxScale: 3.0,),
            ),
            Align(
              alignment: Alignment.topCenter,
              child: Container(
                height: NUIDisplayUtil.statusBarHeight(context) + 20,
                width: screenWidth(context),
                decoration: BoxDecoration(
                    gradient: NUILinearGradient(
                        colors: [
                          NUIColors.NUIShadowBlack.withOpacity(0.4),
                          NUIColors.NUIShadowBlack.withOpacity(0.1),
                          NUIColors.NUITransparent
                        ],
                        orientation: GradientOrientation.T_B
                    )
                ),
              ),
            ),
            Align(
              child: _NUISmallActionButton(icon: Icons.check, onTap: (){
                NUIAsync.run(() async {
                  if(widget.listener != null) widget.listener([await NUIMediaUtil.fileToMediaFile(File(widget.path))]);
                  NUINavigator.pop(context);
                });
              }),
              alignment: Alignment.bottomRight,
            ),
            Align(
              child: _NUISmallActionButton(icon: Icons.clear, onTap: (){
                NUICameraUtil.openCamera(context, enableRecording: widget.enableRecording, listener: widget.listener);
              }),
              alignment: Alignment.bottomLeft,
            ),
          ]
      ),
    );
  }
}


class _NUISmallActionButton extends StatefulWidget {
  _NUISmallActionButton({this.icon, this.onTap, Key key}): super(key: key);
  final IconData icon;
  final Function onTap;
  @override
  _NUISmallActionButtonState createState() => _NUISmallActionButtonState();
}

class _NUISmallActionButtonState extends State<_NUISmallActionButton> {
  @override
  Widget build(BuildContext context) {
    return Container(
      height: 50,
      width: 50,
      margin: EdgeInsets.all(25),
      decoration: NUIOutlineDecoration(
          outlineColor: NUIColors.NUIWhite,
          thickness: 2,
          shadowRadius: 10,
          shadowColor: NUIColors.NUIBlack.withOpacity(0.4),
          radius: BorderRadius.circular(25)
      ),
      padding: EdgeInsets.all(3),
      child: NUIRippleContainer(
        normalColor: NUIColors.NUITransparent,
        rippleColor: NUIColors.NUIBlack.withOpacity(0.4),
        radius: 20,
        borderRadius: BorderRadius.circular(20),
        child: Container(
          width: 40,
          height: 40,
          alignment: Alignment.center,
          child: Icon(widget.icon, color: NUIColors.NUIWhite,),
        ),
        onTap: () {
          if(widget.onTap != null) widget.onTap();
        },
      ),
    );
  }
}

==> nui_media-0.0.9.tar.gz: lib/ui/nui_camera_view.dart <==
import 'dart:io';
import 'package:camera/camera.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:nui_animation/nui_animation.dart';
import 'package:nui_core/nui_core.dart';
import 'package:nui_media/nui_media.dart';

class NUICameraScreenUI extends NUIScreen{
  NUICameraScreenUI(this.cameras, {
    this.resolution: ResolutionPreset.high,
    this.captureButton,
    this.captureButtonMargin,
    this.captureButtonAlignment: Alignment.bottomCenter,
    this.enableVideo: false,
    this.videoMaxDuration,
    this.listener,
    this.preview: true,
    Key key}): super(content : (context) => Scaffold(body: NUICameraUI(cameras: cameras, captureButtonAlignment: captureButtonAlignment, captureButton: captureButton, listener: listener, preview: preview, captureButtonMargin: captureButtonMargin, resolution: resolution, enableVideo: enableVideo, key: key)), screenCode: "NUICameraScreenUI", overlayStyle: NUIOverlayStyle(darkStatusBarIcon: false), key: key);
  final List<CameraDescription> cameras;
  final ResolutionPreset resolution;
  final Widget captureButton;
  final bool enableVideo;
  final Duration videoMaxDuration;
  final Alignment captureButtonAlignment;
  final EdgeInsets captureButtonMargin;
  final MediaSelectionListener listener;
  final bool preview;
}

class NUICameraUI extends StatefulWidget {
  NUICameraUI({
    this.cameras,
    this.resolution: ResolutionPreset.high,
    this.captureButtonMargin,
    this.captureButton,
    this.captureButtonAlignment,
    this.enableVideo: false,
    this.videoMaxDuration,
    this.preview,
    this.listener,
    Key key}): super(key: key);
  final List<CameraDescription> cameras;
  final ResolutionPreset resolution;
  final Widget captureButton;
  final Alignment captureButtonAlignment;
  final bool enableVideo;
  final Duration videoMaxDuration;
  final EdgeInsets captureButtonMargin;
  final MediaSelectionListener listener;
  final bool preview;
  @override
  _NUICameraUIState createState() => _NUICameraUIState();
}

class _NUICameraUIState extends State<NUICameraUI> {
  CameraController _controller;
  int _selectedCameraIndex = 0;
  double scale = 1.0;
  bool isRecording = false;
  bool initiatingRecord = false;
  Future<void> _initializeControllerFuture;
  String recordingVideoPath;


  @override
  void initState(){
    super.initState();
    _initCameraController(widget.cameras[_selectedCameraIndex]);
  }

  void longPress() async{
    print("NUICameraView -> Long pressing");
    if(!widget.enableVideo) return;

    setState(() {
      initiatingRecord = true;
    });
  }

  void capture() async{
    try {
      // Ensure that the camera is initialized.
      await _initializeControllerFuture;

      final file = await NUIMediaUtil.getOutputMediaFile(MediaType.JPG, createFirst: false);
      // Attempt to take a picture and log where it's been saved.
      await _controller.takePicture(file.path);

      if(widget.preview) {
        // If the picture was taken, display it on a new screen.
        NUINavigator.popAndPush(context, NUIImagePreviewUI(imagePath: file.path, enableRecording: widget.enableVideo, listener: widget.listener), transition: PageTransition.RIGHT_LEFT, duration: Duration(milliseconds: 1200));
      }
      else{
        if(widget.listener != null) widget.listener([await NUIMediaUtil.fileToMediaFile(file, type: MediaType.JPG)]);
      }
    } catch (e) {
      // If an error occurs, log the error to the console.
      print(e);
    }
  }

  @override
  void dispose() {
    _controller.dispose();
    super.dispose();
  }

  Widget _getCaptureRecordButton() {
    final captureButton = Container(
      height: 80,
      width: 80,
      decoration: NUIOutlineDecoration(
          outlineColor: NUIColors.NUIWhite,
          thickness: 3,
          shadowRadius: 10,
          shadowColor: NUIColors.NUIBlack.withOpacity(0.4),
          borderRadius: BorderRadius.circular(40)
      ),
      padding: EdgeInsets.all(4),
      child: NUIBouncingAnimation(
        scaleFactor: 1,
        child: !initiatingRecord && !isRecording ? Container(
          width: 70,
          height: 70,
          decoration: BoxDecoration(
              color: NUIColors.NUIWhite,
              shape: BoxShape.circle
          ),
        ) : Container(
          width: 70,
          height: 70,
          alignment: Alignment.center,
          decoration: BoxDecoration(
            color: NUIColors.NUIWhite,
            shape: BoxShape.circle
          ),
          child: !isRecording ? NUIScaleAnimation(
            duration: Duration(milliseconds: 400),
            child: Container(
              width: 55,
              height: 55,
              decoration: BoxDecoration(
                color: NUIColors.NUIAccent,
                shape: BoxShape.circle
              ),
            ),
            endAnimationListener: () {
              initiatingRecord = false;
              isRecording = true;
            },
          ) : Container(
            width: 55,
            height: 55,
            decoration: BoxDecoration(
                color: NUIColors.NUIAccent,
                shape: BoxShape.circle
            ),
          ),
        ),
        onTap: () {
          capture();
        },
        onLongPress: () {
          longPress();
        },
      ),
    );
    return captureButton;
  }


  Widget _getCaptureButton(){
    Widget captureButton;
    if(widget.captureButton != null){
      captureButton = GestureDetector(
        child: widget.captureButton,
        onTap: (){
          capture();
        },
      );
    }
    else {
      captureButton = _getCaptureRecordButton();
    }

    return Container(
      margin: widget.captureButtonMargin ?? EdgeInsets.all(30),
      child: captureButton,
    );
  }

  Widget _cameraTogglesWidget() {
    if (widget.cameras == null || widget.cameras.isEmpty) {
      return Spacer();
    }

    CameraDescription selectedCamera = widget.cameras[_selectedCameraIndex];
    CameraLensDirection lensDirection = selectedCamera.lensDirection;

    return _NUISmallActionButton(icon: _getCameraLensIcon(lensDirection), onTap: (){
      _switchCamera();
    });
  }

  void _switchCamera() {
    if(widget.cameras.length > 1) {
      _selectedCameraIndex = _selectedCameraIndex == 0 ? 1 : 0;
      CameraDescription selectedCamera = widget.cameras[_selectedCameraIndex];
      _initCameraController(selectedCamera);
    }
  }

  Future _initCameraController(CameraDescription cameraDescription) async {
    if (_controller != null) {
      await _controller.dispose();
    }

    _controller = CameraController(cameraDescription, widget.resolution ?? ResolutionPreset.high);

    _controller.addListener(() {
      if (mounted) {
        setState(() {});
      }

      if (_controller.value.hasError) {
        print('Camera error ${_controller.value.errorDescription}');
      }
    });

    try {
      _initializeControllerFuture = _controller.initialize();
    } on CameraException catch (e) {
//      _showCameraException(e);
    }

    if (mounted) {
      print("NUICameraView -> Camera mounted");
      setState(() {

      });
    }
  }

  IconData _getCameraLensIcon(CameraLensDirection direction) {
    switch (direction) {
      case CameraLensDirection.back:
        return Icons.camera_rear;
      case CameraLensDirection.front:
        return Icons.camera_front;
      case CameraLensDirection.external:
        return Icons.camera;
      default:
        return Icons.device_unknown;
    }
  }

  void _onRecordButtonPressed() {
    _startVideoRecording().then((String filePath) {
      if (filePath != null) {
        toast("Recording video started", context: context);
      }
    });
  }

  void _onStopButtonPressed() {
    _stopVideoRecording().then((_) {
      if (mounted) setState(() {});
      toast("Video recorded to $recordingVideoPath", context: context);
    });
  }

  Future<String> _startVideoRecording() async {
    if (!_controller.value.isInitialized) {
      toast("Please wait", context: context);
      return null;
    }

    // Do nothing if a recording is on progress
    if (_controller.value.isRecordingVideo) {
      return null;
    }

    final File file = await NUIMediaUtil.getOutputMediaFile(MediaType.MP4, createFirst: false);
    final String filePath = file.path;

    try {
      await _controller.startVideoRecording(filePath);
      recordingVideoPath = filePath;
    } on CameraException catch (e) {
      _showCameraException(e);
      return null;
    }
    return filePath;
  }

  Future<void> _stopVideoRecording() async {
    if (!_controller.value.isRecordingVideo) {
      return null;
    }
    try {
      await _controller.stopVideoRecording();
    } on CameraException catch (e) {
      _showCameraException(e);
      return null;
    }
  }

  void _showCameraException(CameraException e) {
    String errorText = 'Error: ${e.code}\nError Message: ${e.description}';
    print(errorText);

    toast("Error: ${e.code}\n${e.description}", context: context);
  }

  @override
  Widget build(BuildContext context) {
    Widget preview;
    if (_controller == null || !_controller.value.isInitialized) {
      preview = Center(child: CircularProgressIndicator());
    }
    else {
      preview = GestureDetector(
          onScaleUpdate: (one) {
//            scale = one.scale;
//            setState(() {
//
//            });
          },
          child: Transform.scale(
              scale: scale,
              child: Center(child: AspectRatio(
                  aspectRatio: _controller.value.aspectRatio,
                  child: CameraPreview(_controller)))
          )
      );
    }

    return Container(
      color: NUIColors.NUIBlack,
      child: Stack(
          children: [
            preview,
            Align(
              alignment: Alignment.topCenter,
              child: Container(
                height: NUIDisplayUtil.statusBarHeight(context) + 20,
                width: screenWidth(context),
                decoration: BoxDecoration(
                    gradient: NUILinearGradient(
                        colors: [
                          NUIColors.NUIShadowBlack.withOpacity(0.4),
                          NUIColors.NUIShadowBlack.withOpacity(0.1),
                          NUIColors.NUITransparent
                        ],
                        orientation: GradientOrientation.T_B
                    )
                ),
              ),
            ),
            Visibility(
                visible: widget.cameras.length > 1,
                child: Align(
                  child: _cameraTogglesWidget(),
                  alignment: Alignment.bottomLeft,
                )
            ),
            Align(
              child: _getCaptureButton(),
              alignment: widget.captureButtonAlignment ??
                  Alignment.bottomCenter,
            )
          ]
      ),
    );
  }
}

class NUIImagePreviewUI extends NUIScreen {
  final String imagePath;
  final MediaSelectionListener listener;
  final bool enableRecording;

  NUIImagePreviewUI({Key key, this.imagePath, this.listener, this.enableRecording}) : super(
      content : (context) => _NUICameraPreviewContentUI(imagePath, listener: listener, enableRecording: enableRecording,), screenCode: "NUIImagePreviewUI", key: key, overlayStyle: NUIOverlayStyle(darkStatusBarIcon: false));
}

class _NUICameraPreviewContentUI extends StatefulWidget {
  _NUICameraPreviewContentUI(this.path, {this.listener, this.enableRecording});
  final String path;
  final MediaSelectionListener listener;
  final bool enableRecording;

  @override
  __NUICameraPreviewContentUIState createState() => __NUICameraPreviewContentUIState();
}

class __NUICameraPreviewContentUIState extends State<_NUICameraPreviewContentUI> {

  @override
  Widget build(BuildContext context) {
    return Container(
      color: NUIColors.NUIBlack,
      child: Stack(
          children: [
            Center(
              child: InteractiveViewer(child: Image.file(File(widget.path)), maxScale: 3.0,),
            ),
            Align(
              alignment: Alignment.topCenter,
              child: Container(
                height: NUIDisplayUtil.statusBarHeight(context) + 20,
                width: screenWidth(context),
                decoration: BoxDecoration(
                    gradient: NUILinearGradient(
                        colors: [
                          NUIColors.NUIShadowBlack.withOpacity(0.4),
                          NUIColors.NUIShadowBlack.withOpacity(0.1),
                          NUIColors.NUITransparent
                        ],
                        orientation: GradientOrientation.T_B
                    )
                ),
              ),
            ),
            Align(
              child: _NUISmallActionButton(icon: Icons.check, onTap: (){
                NUIAsync.run(() async {
                  if(widget.listener != null) widget.listener([await NUIMediaUtil.fileToMediaFile(File(widget.path))]);
                  NUINavigator.pop(context);
                });
              }),
              alignment: Alignment.bottomRight,
            ),
            Align(
              child: _NUISmallActionButton(icon: Icons.clear, onTap: (){
                NUICameraUtil.openCamera(context, enableRecording: widget.enableRecording, listener: widget.listener);
              }),
              alignment: Alignment.bottomLeft,
            ),
          ]
      ),
    );
  }
}


class _NUISmallActionButton extends StatefulWidget {
  _NUISmallActionButton({this.icon, this.onTap, Key key}): super(key: key);
  final IconData icon;
  final Function onTap;
  @override
  _NUISmallActionButtonState createState() => _NUISmallActionButtonState();
}

class _NUISmallActionButtonState extends State<_NUISmallActionButton> {
  @override
  Widget build(BuildContext context) {
    return Container(
      height: 50,
      width: 50,
      margin: EdgeInsets.all(25),
      decoration: NUIOutlineDecoration(
          outlineColor: NUIColors.NUIWhite,
          thickness: 2,
          shadowRadius: 10,
          shadowColor: NUIColors.NUIBlack.withOpacity(0.4),
          borderRadius: BorderRadius.circular(25)
      ),
      padding: EdgeInsets.all(3),
      child: NUIRippleContainer(
        normalColor: NUIColors.NUITransparent,
        rippleColor: NUIColors.NUIBlack.withOpacity(0.4),
        radius: 20,
        borderRadius: BorderRadius.circular(20),
        child: Container(
          width: 40,
          height: 40,
          alignment: Alignment.center,
          child: Icon(widget.icon, color: NUIColors.NUIWhite,),
        ),
        onTap: () {
          if(widget.onTap != null) widget.onTap();
        },
      ),
    );
  }
}
